@@ -1,4 +1,5 @@
 import json
+import logging
 import os
 import uuid
 from datetime import datetime
@@ -9,7 +10,7 @@ from .remote_queue import RemoteQueueClient
 QUEUE_FILE = os.getenv("QUEUE_FILE_PATH", "queue.json")
 
 class PyQueue:
-    def __init__(self, queue_file=QUEUE_FILE, queue_type="local", server_url=None, queue_name="default", timeout=30):
+    def __init__(self, queue_file=QUEUE_FILE, queue_type="local", server_url=None, api_key=None, queue_name="default", timeout=30):
         """
         Initialize PyQueue client
         
@@ -21,6 +22,7 @@ class PyQueue:
             timeout: Request timeout for remote operations
         """
         self.queue_type = queue_type.lower()
+        self.logger = logging.getLogger(__name__)
         
         if self.queue_type == "local":
             self.queue_file = queue_file
@@ -32,7 +34,7 @@ class PyQueue:
         elif self.queue_type == "remote":
             if not server_url:
                 raise ValueError("server_url is required when queue_type='remote'")
-            self.remote_client = RemoteQueueClient(server_url, queue_name, timeout)
+            self.remote_client = RemoteQueueClient(server_url, queue_name, api_key, timeout)
             
         else:
             raise ValueError("queue_type must be 'local' or 'remote'")
@@ -74,7 +76,7 @@ class PyQueue:
         with open(self.queue_file, "w") as f:
             json.dump(queue, f, indent=4)
 
-        print(f"✅ Message added: {item_queue['id']}")
+        self.logger.info(f"✅ Message added: {item_queue['id']}")
 
     def get_messages(self):
         """Returns all messages from the queue"""
@@ -84,18 +86,45 @@ class PyQueue:
         # Local queue implementation
         with open(self.queue_file, "r") as f:
             return json.load(f)
+
+    def get_message(self, item_id):
+        """Returns a specific message by ID if it exists, otherwise None"""
+        # Get all messages (works for both local and remote)
+        messages = self.get_messages()
+        
+        # Find the specific message
+        for item in messages:
+            if item.get("id") == item_id:
+                return item
+        return None
+
+    def has_message(self, item_id):
+        """Checks if a message exists in the queue"""
+        return self.get_message(item_id) is not None
     
-    def receive_messages(self, max_messages=10, visibility_timeout=30):
+    def receive_messages(self, max_messages=10, visibility_timeout=30, delete_after_receive=False, only_new=False):
         """
         Receive messages from the queue (SQS-style)
-        For local queues, this is the same as get_messages
-        For remote queues, messages become temporarily invisible
+        For remote queues, messages become temporarily invisible or are deleted immediately.
+        For local queues, optionally delete the messages after reading.
+        The only_new flag is only supported for remote queues.
         """
         if self.queue_type == "remote":
-            return self.remote_client.receive_messages(max_messages, visibility_timeout)
+            return self.remote_client.receive_messages(max_messages, visibility_timeout, delete_after_receive, only_new)
             
-        # Local queue implementation - just return messages
-        return self.get_messages()[:max_messages]
+        # Local queue implementation
+        if only_new:
+            self.logger.warning("only_new flag is not supported for local queues; returning all messages.")
+        messages = self.get_messages()
+        selected_messages = messages[:max_messages]
+
+        if delete_after_receive and selected_messages:
+            remaining_messages = messages[max_messages:]
+            with open(self.queue_file, "w") as f:
+                json.dump(remaining_messages, f, indent=4)
+            self.logger.info(f"🗑 Deleted {len(selected_messages)} message(s) after receive")
+
+        return selected_messages
 
     def clear_queue(self):
         """Clears the queue"""
@@ -105,7 +134,7 @@ class PyQueue:
         # Local queue implementation
         with open(self.queue_file, "w") as f:
             json.dump([], f)
-        print("🚀 Queue cleared!")
+        self.logger.info("🚀 Queue cleared!")
 
     def remove_message(self, item_id):
         """Removes a message from the queue"""
@@ -120,7 +149,7 @@ class PyQueue:
 
         with open(self.queue_file, "w") as f:
             json.dump(new_queue, f, indent=4)
-        print(f"🗑 Message removed: {item_id}")
+        self.logger.info(f"🗑 Message removed: {item_id}")
 
     def update_message(self, item_id, new_message):
         """Updates a message in the queue"""
@@ -139,7 +168,7 @@ class PyQueue:
 
         with open(self.queue_file, "w") as f:
             json.dump(queue, f, indent=4)
-        print(f"🔄 Message updated: {new_message}")
+        self.logger.info(f"🔄 Message updated: {new_message}")
     
     def delete_message(self, receipt_handle: str):
         """
